#############
BPTK In Depth
#############

This section explains the architecture of the BPTK framework and goes into the details of how to build models using System Dynamics and agent-based modeling.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ./in_depth_abm/in_depth_abm
   ./in_depth_architecture/in_depth_architecture
   ./in_depth_sd_dsl/in_depth_sd_dsl

